#[non_exhaustive]pub enum ModuleConfigError {
ModuleNotFound {
id: ModuleInstanceId,
},
KindNotFound {
kind: ModuleKind,
},
WrongType {
kind: ModuleKind,
expected: &'static str,
},
NotDecoded {
id: ModuleInstanceId,
kind: ModuleKind,
},
UnsupportedModule {
id: ModuleInstanceId,
kind: ModuleKind,
},
Meta {
key: String,
source: Error,
},
Json(Error),
Decode(DecodeError),
}Expand description
Failure to look up or cast a module configuration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ModuleNotFound
No module with this instance id exists in the config.
Fields
KindNotFound
No module of this kind exists in the config.
Fields

kind: ModuleKindWrongType
The decoded module config is not of the requested type.
NotDecoded
The module config is still in its raw, undecoded form because no
decoder for its kind was available; see
ClientModuleConfig::redecode_raw.
UnsupportedModule
The config references a module kind this build has no support for.
Meta
A meta field exists but does not deserialize to the requested type.
Json(Error)
A JSON part of the config failed to (de)serialize.
Decode(DecodeError)
A consensus-encoded part of the config failed to decode.